@@ -6,7 +6,7 @@ use 5.008001;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build or find libtool
-our $VERSION = '0.08_01'; # TRIAL VERSION
+our $VERSION = '0.10_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -29,7 +29,7 @@ Alien::libtool - Build or find libtool
 
 =head1 VERSION
 
-version 0.08_01
+version 0.10_01
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ In your script or module:
  use Alien::libtool;
  use Env qw( @PATH );
  
- unshift @ENV, Alien::libtool->bin_dir;
+ unshift @PATH, Alien::libtool->bin_dir;
 
 =head1 DESCRIPTION
 
